from django.core.urlresolvers import reverse
from django.views.generic import TemplateView
from django.conf import settings


class GraphiQL(TemplateView):
    template_name = 'graphiql/index.html'
    graphql_url = None

    def get_context_data(self, **kwargs):
        context = super(GraphiQL, self).get_context_data(**kwargs)
        default_query = getattr(settings, 'GRAPHIQL_DEFAULT_QUERY', None)
        graphql_url = getattr(settings, 'GRAPHIQL_GRAPHQL_URL', '/graphql')
        graphql_viewname = getattr(settings, 'GRAPHIQL_GRAPHQL_VIEWNAME', None)
        if graphql_viewname:
            graphql_url = reverse(graphql_viewname)

        context['default_query'] = default_query
        context['graphql_url'] = self.graphql_url or graphql_url
        return context



from setuptools import setup, find_packages

setup(
    name='django-graphiql',
    version='0.3.1.8',
    download_url='git@github.com:graphql-python/django-graphiql.git',
    packages=find_packages(),
    author='Syrus Akbary',
    author_email='me@syrusakbary.com',
    description='Integrate GraphiQL easily into your Django project',
    long_description=open('README.rst').read(),
    keywords='django graphiql graphql graphene graphql-core',
    url='http://github.com/graphql-python/django-graphiql',
    license='MIT',
    entry_points={
    },
    install_requires=['django>=1.7'],
    tests_require=[],
    include_package_data=True,
    zip_safe=False,
    platforms='any',
)
